#!/bin/bash

# quick script to analyze the output of showq to determine my place in line
# for a pending job

username=cdowns

# get a formatted list of allt he jobs running
squeue -o "%.10i %.12P %.16j %.8u %.10T %.10M %.10L %.6D %.10r  %p" > tmp_joblist.txt

# now split the joblist into the architecture types
cat tmp_joblist.txt | grep -v "skx-[d,l,n]" > tmp_joblist_KNL.txt
cat tmp_joblist.txt | grep "skx-[d,l,n]" > tmp_joblist_SKX.txt

for arch in KNL SKX; do

  jobfile="tmp_joblist_${arch}.txt"

  # first print the jobs running
  echo ""
  echo "### ${arch}: Current Jobs Running:"
  echo " Pos  `head -n 1 tmp_joblist.txt`" 
  positions=`cat -n ${jobfile} | grep ${username} | grep RUNNING | awk '{print $1}'`
  for position in $positions; do
    echo "$position  `head -n $position ${jobfile} | tail -n 1`"
  done

  # now for every one of my waiting jobs, list the number of nodes ahead and the run position
  echo ""
  echo "### ${arch}: Current Jobs Waiting:"
  echo "Ahead Pos  `head -n 1 tmp_joblist.txt`" 
  positions=`cat -n ${jobfile} | grep ${username} | grep PENDING | awk '{print $1}'`
  for position in $positions; do
    pnm1=$[position-1]
    pnm2=$[position-2]
    nodes_ahead=`head -n $pnm1 ${jobfile} | tail -n $pnm2 | awk '{sum += $8} END {print sum}'`
    echo "$nodes_ahead  $position  `head -n $position ${jobfile} | tail -n 1`"
  done

  total_running=`cat ${jobfile} | grep RUNNING | awk '{sum += $8} END {print sum}'`
  echo ""
  echo "${arch}: $total_running nodes are currently running"
  echo ""

done

\rm tmp_joblist.txt
\rm tmp_joblist_KNL.txt
\rm tmp_joblist_SKX.txt


